.. :changelog:

History
-------

0.29 (2016-11)
++++++++++++++++++

* Update package name


0.28 (2016-10)
++++++++++++++++++

* Fix total property not found in page resource
* Require requests >= 1.2.3.
